@@ -80,7 +80,7 @@ static dReal speed=0,steer=0;	// user commands
 // this is called by dSpaceCollide when two objects in space are
 // potentially colliding.
 
-static void nearCallback (void *data, dGeomID o1, dGeomID o2)
+static void nearCallback (void *, dGeomID o1, dGeomID o2)
 {
   int i,n;
 
@@ -186,6 +186,7 @@ static void simLoop (int pause)
 
     // remove all contact joints
     dJointGroupEmpty (contactgroup);
+
   }
 
   dsSetColor (0,1,1);
@@ -200,13 +201,6 @@ static void simLoop (int pause)
   dGeomBoxGetLengths (ground_box,ss);
   dsDrawBox (dGeomGetPosition(ground_box),dGeomGetRotation(ground_box),ss);
 
-  /*
-  printf ("%.10f %.10f %.10f %.10f\n",
-	  dJointGetHingeAngle (joint[1]),
-	  dJointGetHingeAngle (joint[2]),
-	  dJointGetHingeAngleRate (joint[1]),
-	  dJointGetHingeAngleRate (joint[2]));
-  */
 }
 
 
@@ -257,16 +251,6 @@ int main (int argc, char **argv)
   dBodySetPosition (body[2],-0.5*LENGTH, WIDTH*0.5,STARTZ-HEIGHT*0.5);
   dBodySetPosition (body[3],-0.5*LENGTH,-WIDTH*0.5,STARTZ-HEIGHT*0.5);
 
-  // front wheel hinge
-  /*
-  joint[0] = dJointCreateHinge2 (world,0);
-  dJointAttach (joint[0],body[0],body[1]);
-  const dReal *a = dBodyGetPosition (body[1]);
-  dJointSetHinge2Anchor (joint[0],a[0],a[1],a[2]);
-  dJointSetHinge2Axis1 (joint[0],0,0,1);
-  dJointSetHinge2Axis2 (joint[0],0,1,0);
-  */
-
   // front and back wheel hinges
   for (i=0; i<3; i++) {
     joint[i] = dJointCreateHinge2 (world,0);
