@@ -23,6 +23,7 @@
 // This is a demo of the QuickStep and StepFast methods,
 // originally by David Whittaker.
 
+
 #include <ode/ode.h>
 #include <drawstuff/drawstuff.h>
 #include "texturepath.h"
@@ -41,10 +42,6 @@
 #endif
 
 
-// select the method you want to test here (only uncomment *one* line)
-#define QUICKSTEP 1
-//#define STEPFAST 1
-
 // some constants
 
 #define LENGTH 3.5		// chassis length
@@ -84,6 +81,8 @@
 
 static dWorldID world;
 static dSpaceID space;
+static dThreadingImplementationID threading;
+static dThreadingThreadPoolID pool;
 static dBodyID body[10000];
 static int bodies;
 static dJointID joint[100000];
@@ -115,7 +114,7 @@ static dReal cannon_angle=0,cannon_elevation=-1.2;
 // this is called by dSpaceCollide when two objects in space are
 // potentially colliding.
 
-static void nearCallback (void *data, dGeomID o1, dGeomID o2)
+static void nearCallback (void *, dGeomID o1, dGeomID o2)
 {
 	int i,n;
 	
@@ -165,8 +164,6 @@ static void start()
 			"\t'2' to lower the cannon.\n"
 			"\t'x' to shoot from the cannon.\n"
 			"\t'f' to toggle fast step mode.\n"
-			"\t'+' to increase AutoEnableDepth.\n"
-			"\t'-' to decrease AutoEnableDepth.\n"
 			"\t'r' to reset simulation.\n");
 }
 
@@ -234,19 +231,29 @@ void makeCar(dReal x, dReal y, int &bodyI, int &jointI, int &boxI, int &sphereI)
 	sphereI	+= 4;
 }
 
+static 
+void shutdownSimulation()
+{
+    // destroy world if it exists
+    if (bodies)
+    {
+        dThreadingImplementationShutdownProcessing(threading);
+        dThreadingFreeThreadPool(pool);
+        dWorldSetStepThreadingImplementation(world, NULL, NULL);
+        dThreadingFreeImplementation(threading);
 
-void resetSimulation()
+        dJointGroupDestroy (contactgroup);
+        dSpaceDestroy (space);
+        dWorldDestroy (world);
+
+        bodies = 0;
+    }
+}
+
+static 
+void setupSimulation()
 {
 	int i;
-	i = 0;
-	// destroy world if it exists
-	if (bodies)
-	{
-		dJointGroupDestroy (contactgroup);
-		dSpaceDestroy (space);
-		dWorldDestroy (world);
-	}
-	
 	for (i = 0; i < 1000; i++)
 		wb_stepsdis[i] = 0;
 
@@ -263,6 +270,14 @@ void resetSimulation()
 	dWorldSetCFM (world, 1e-5);
 	dWorldSetERP (world, 0.8);
 	dWorldSetQuickStepNumIterations (world,ITERS);
+
+    threading = dThreadingAllocateMultiThreadedImplementation();
+    pool = dThreadingAllocateThreadPool(4, 0, dAllocateFlagBasicData, NULL);
+    dThreadingThreadPoolServeMultiThreadedImplementation(pool, threading);
+    // dWorldSetStepIslandsProcessingMaxThreadCount(world, 1);
+    dWorldSetStepThreadingImplementation(world, dThreadingImplementationGetFunctions(threading), threading);
+
+
 	ground = dCreatePlane (space,0,0,1,0);
 	
 	bodies = 0;
@@ -451,14 +466,9 @@ static void command (int cmd)
 	case 'f': case 'F':
 		doFast = !doFast;
 		break;
-	case '+':
-		dWorldSetAutoEnableDepthSF1 (world, dWorldGetAutoEnableDepthSF1 (world) + 1);
-		break;
-	case '-':
-		dWorldSetAutoEnableDepthSF1 (world, dWorldGetAutoEnableDepthSF1 (world) - 1);
-		break;
 	case 'r': case 'R':
-		resetSimulation();
+        shutdownSimulation();
+		setupSimulation();
 		break;
 	case '[':
 		cannon_angle += 0.1;
@@ -515,11 +525,7 @@ static void simLoop (int pause)
 		if (doFast)
 		{
 			dSpaceCollide (space,0,&nearCallback);
-#if defined(QUICKSTEP)
 			dWorldQuickStep (world,0.05);
-#elif defined(STEPFAST)
-			dWorldStepFast1 (world,0.05,ITERS);
-#endif
 			dJointGroupEmpty (contactgroup);
 		}
 		else
@@ -625,14 +631,12 @@ int main (int argc, char **argv)
 	boxes = 0;
 	spheres = 0;
 	
-	resetSimulation();
+	setupSimulation();
 	
 	// run simulation
 	dsSimulationLoop (argc,argv,352,288,&fn);
 	
-	dJointGroupDestroy (contactgroup);
-	dSpaceDestroy (space);
-	dWorldDestroy (world);
+	shutdownSimulation();
 	dCloseODE();
 	return 0;
 }
