@@ -74,7 +74,7 @@ static void nearCallback (void *data, dGeomID o1, dGeomID o2)
 
   if (dGeomIsSpace(o1) || dGeomIsSpace(o2))
   {
-    fprintf(stderr,"testing space %p %p\n", o1,o2);
+      fprintf(stderr,"testing space %p %p\n", (void*)o1, (void*)o2);
     // colliding a space with something
     dSpaceCollide2(o1,o2,data,&nearCallback);
     // Note we do not want to test intersections within a space,
