@@ -21,6 +21,8 @@
  *************************************************************************/
 
 
+#include <ode/odeconfig.h>
+#include "config.h"
 #include "universal.h"
 #include "joint_internal.h"
 
@@ -35,7 +37,7 @@
 // implementation (or, less likely, the hinge2 implementation).
 
 dxJointUniversal::dxJointUniversal( dxWorld *w ) :
-        dxJoint( w )
+    dxJoint( w )
 {
     dSetZero( anchor1, 4 );
     dSetZero( anchor2, 4 );
@@ -54,11 +56,11 @@ void
 dxJointUniversal::getAxes( dVector3 ax1, dVector3 ax2 )
 {
     // This says "ax1 = joint->node[0].body->posr.R * joint->axis1"
-    dMULTIPLY0_331( ax1, node[0].body->posr.R, axis1 );
+    dMultiply0_331( ax1, node[0].body->posr.R, axis1 );
 
     if ( node[1].body )
     {
-        dMULTIPLY0_331( ax2, node[1].body->posr.R, axis2 );
+        dMultiply0_331( ax2, node[1].body->posr.R, axis2 );
     }
     else
     {
@@ -253,6 +255,13 @@ dxJointUniversal::getAngle2()
 }
 
 
+void 
+dxJointUniversal::getSureMaxInfo( SureMaxInfo* info )
+{
+    info->max_m = 6;
+}
+
+
 void
 dxJointUniversal::getInfo1( dxJoint::Info1 *info )
 {
@@ -260,9 +269,9 @@ dxJointUniversal::getInfo1( dxJoint::Info1 *info )
     info->m = 4;
 
     bool limiting1 = ( limot1.lostop >= -M_PI || limot1.histop <= M_PI ) &&
-                     limot1.lostop <= limot1.histop;
+        limot1.lostop <= limot1.histop;
     bool limiting2 = ( limot2.lostop >= -M_PI || limot2.histop <= M_PI ) &&
-                     limot2.lostop <= limot2.histop;
+        limot2.lostop <= limot2.histop;
 
     // We need to call testRotationLimit() even if we're motored, since it
     // records the result.
@@ -285,10 +294,10 @@ dxJointUniversal::getInfo1( dxJoint::Info1 *info )
 
 
 void
-dxJointUniversal::getInfo2( dxJoint::Info2 *info )
+dxJointUniversal::getInfo2( dReal worldFPS, dReal worldERP, const Info2Descr *info )
 {
     // set the three ball-and-socket rows
-    setBall( this, info, anchor1, anchor2 );
+    setBall( this, worldFPS, worldERP, info, anchor1, anchor2 );
 
     // set the universal joint row. the angular velocity about an axis
     // perpendicular to both joint axes should be equal. thus the constraint
@@ -309,11 +318,11 @@ dxJointUniversal::getInfo2( dxJoint::Info2 *info )
     // we find a axis2_tmp which is really perpendicular to axis1
     // and in the plane of axis1 and axis2
     getAxes( ax1, ax2 );
-    k = dDOT( ax1, ax2 );
+    k = dCalcVectorDot3( ax1, ax2 );
     ax2_temp[0] = ax2[0] - k * ax1[0];
     ax2_temp[1] = ax2[1] - k * ax1[1];
     ax2_temp[2] = ax2[2] - k * ax1[2];
-    dCROSS( p, = , ax1, ax2_temp );
+    dCalcVectorCross3( p, ax1, ax2_temp );
     dNormalize3( p );
 
     int s3 = 3 * info->rowskip;
@@ -343,13 +352,13 @@ dxJointUniversal::getInfo2( dxJoint::Info2 *info )
     // theta - Pi/2 ~= cos(theta), so
     //    |angular_velocity|  ~= (erp*fps) * (ax1 dot ax2)
 
-    info->c[3] = info->fps * info->erp * - k;
+    info->c[3] = worldFPS * worldERP * - k;
 
     // if the first angle is powered, or has joint limits, add in the stuff
-    int row = 4 + limot1.addLimot( this, info, 4, ax1, 1 );
+    int row = 4 + limot1.addLimot( this, worldFPS, info, 4, ax1, 1 );
 
     // if the second angle is powered, or has joint limits, add in more stuff
-    limot2.addLimot( this, info, row, ax2, 1 );
+    limot2.addLimot( this, worldFPS, info, row, ax2, 1 );
 }
 
 
@@ -408,7 +417,7 @@ void dJointSetUniversalAxis1( dJointID j, dReal x, dReal y, dReal z )
 }
 
 void dJointSetUniversalAxis1Offset( dJointID j, dReal x, dReal y, dReal z,
-                                    dReal offset1, dReal offset2 )
+                                   dReal offset1, dReal offset2 )
 {
     dxJointUniversal* joint = ( dxJointUniversal* )j;
     dUASSERT( joint, "bad joint argument" );
@@ -483,7 +492,7 @@ void dJointSetUniversalAxis2( dJointID j, dReal x, dReal y, dReal z )
 }
 
 void dJointSetUniversalAxis2Offset( dJointID j, dReal x, dReal y, dReal z,
-                                    dReal offset1, dReal offset2 )
+                                   dReal offset1, dReal offset2 )
 {
     dxJointUniversal* joint = ( dxJointUniversal* )j;
     dUASSERT( joint, "bad joint argument" );
@@ -686,9 +695,9 @@ dReal dJointGetUniversalAngle1Rate( dJointID j )
         else
             getAxis( joint, axis, joint->axis1 );
 
-        dReal rate = dDOT( axis, joint->node[0].body->avel );
+        dReal rate = dCalcVectorDot3( axis, joint->node[0].body->avel );
         if ( joint->node[1].body )
-            rate -= dDOT( axis, joint->node[1].body->avel );
+            rate -= dCalcVectorDot3( axis, joint->node[1].body->avel );
         return rate;
     }
     return 0;
@@ -710,8 +719,8 @@ dReal dJointGetUniversalAngle2Rate( dJointID j )
         else
             getAxis2( joint, axis, joint->axis2 );
 
-        dReal rate = dDOT( axis, joint->node[0].body->avel );
-        if ( joint->node[1].body ) rate -= dDOT( axis, joint->node[1].body->avel );
+        dReal rate = dCalcVectorDot3( axis, joint->node[0].body->avel );
+        if ( joint->node[1].body ) rate -= dCalcVectorDot3( axis, joint->node[1].body->avel );
         return rate;
     }
     return 0;
