@@ -36,7 +36,7 @@
 
 #if _OU_TARGET_OS == _OU_TARGET_OS_WINDOWS
 
-#include <Windows.h>
+#include <windows.h>
 
 
 #else // #if _OU_TARGET_OS != _OU_TARGET_OS_WINDOWS
@@ -164,7 +164,7 @@ public: // Safe methods
 	 *	called anyway, there is no sense in creating additional overload without
 	 *	destructor parameter which would preserve current destructor procedure.
 	 */
-	static _OU_ALWAYSINLINE_PRE bool _OU_ALWAYSINLINE_IN _OU_CONVENTION_API 
+	static _OU_ALWAYSINLINE bool _OU_CONVENTION_API 
 	/*bool */SetStorageValue(const HTLSKEY &hskStorageKey, tlsindextype iValueIndex, tlsvaluetype vValueData, CTLSValueDestructor fnValueDestructor=NULL)
 	{
 		bool bResult;
@@ -186,7 +186,7 @@ public: // Safe methods
 		return bResult;
 	}
 
-	static _OU_ALWAYSINLINE_PRE tlsvaluetype _OU_ALWAYSINLINE_IN _OU_CONVENTION_API 
+	static _OU_ALWAYSINLINE tlsvaluetype _OU_CONVENTION_API 
 	/*tlsvaluetype */GetStorageValue(const HTLSKEY &hskStorageKey, tlsindextype iValueIndex)
 	{
 		tlsvaluetype vValueData = 0;
@@ -202,14 +202,14 @@ public: // Safe methods
 	}
 
 public: // Unsafe methods
-	static _OU_ALWAYSINLINE_PRE void _OU_ALWAYSINLINE_IN _OU_CONVENTION_API 
+	static _OU_ALWAYSINLINE void _OU_CONVENTION_API 
 	/*void */UnsafeSetStorageValue(const HTLSKEY &hskStorageKey, tlsindextype iValueIndex, tlsvaluetype vValueData)
 	{
 		CTLSStorageBlock *psbStorageBlock = GetKeyStorageBlock(hskStorageKey);
 		psbStorageBlock->SetValueData(iValueIndex, vValueData);
 	}
 
-	static _OU_ALWAYSINLINE_PRE tlsvaluetype _OU_ALWAYSINLINE_IN _OU_CONVENTION_API 
+	static _OU_ALWAYSINLINE tlsvaluetype _OU_CONVENTION_API 
 	/*tlsvaluetype */UnsafeGetStorageValue(const HTLSKEY &hskStorageKey, tlsindextype iValueIndex)
 	{
 		CTLSStorageBlock *psbStorageBlock = GetKeyStorageBlock(hskStorageKey);
