@@ -16,12 +16,20 @@ TEST(test_collision_trimesh_sphere_exact)
     return;
     #endif
 
-    dInitODE();
-
     {
         const int VertexCount = 4;
         const int IndexCount = 2*3;
         // this is a square on the XY plane
+        /*
+           3    2
+           +----+
+           |   /|
+           |  / |
+           | /  |
+           |/   |
+           +----+
+           0    1
+         */
         float vertices[VertexCount * 3] = {
             -1,-1,0,
             1,-1,0,
@@ -44,22 +52,29 @@ TEST(test_collision_trimesh_sphere_exact)
         dGeomID trimesh = dCreateTriMesh(0, data, 0, 0, 0);
         const dReal radius = 4;
         dGeomID sphere = dCreateSphere(0, radius);
-        dGeomSetPosition(sphere, 0,0,radius);
         dContactGeom cg[4];
         int nc;
+        dVector3 trinormal = { 0, 0, -1 };
 
-        // check extreme case
+        // Test case: sphere touches the diagonal edge
+        dGeomSetPosition(sphere, 0,0,radius);
         nc = dCollide(trimesh, sphere, 4, &cg[0], sizeof cg[0]);
-        CHECK_EQUAL(1, nc);
-        CHECK_EQUAL(0, cg[0].depth);
+        CHECK_EQUAL(2, nc);
+        for (int i=0; i<nc; ++i) {
+            CHECK_EQUAL(0, cg[i].depth);
+            CHECK_ARRAY_EQUAL(trinormal, cg[i].normal, 3);
+        }
         
         // now translate both geoms
         dGeomSetPosition(trimesh, 10,30,40);
         dGeomSetPosition(sphere, 10,30,40+radius);
         // check extreme case, again
         nc = dCollide(trimesh, sphere, 4, &cg[0], sizeof cg[0]);
-        CHECK_EQUAL(1, nc);
-        CHECK_EQUAL(0, cg[0].depth);
+        CHECK_EQUAL(2, nc);
+        for (int i=0; i<nc; ++i) {
+            CHECK_EQUAL(0, cg[i].depth);
+            CHECK_ARRAY_EQUAL(trinormal, cg[i].normal, 3);
+        }
         
         // and now, let's rotate the trimesh, 90 degrees on X
         dMatrix3 rot = { 1, 0, 0, 0,
@@ -71,10 +86,13 @@ TEST(test_collision_trimesh_sphere_exact)
         dGeomSetPosition(sphere, 10,30-radius,40);
         // check extreme case, again
         nc = dCollide(trimesh, sphere, 4, &cg[0], sizeof cg[0]);
-        CHECK_EQUAL(1, nc);
-        CHECK_EQUAL(0, cg[0].depth);
+        CHECK_EQUAL(2, nc);
+        dVector3 rtrinormal = { 0, 1, 0 };
+        for (int i=0; i<nc; ++i) {
+            CHECK_EQUAL(0, cg[i].depth);
+            CHECK_ARRAY_EQUAL(rtrinormal, cg[i].normal, 3);
+        }
     }
-    dCloseODE();
 }
 
 
@@ -85,7 +103,6 @@ TEST(test_collision_heightfield_ray_fail)
      * This test demonstrated a bug in the AABB handling of the
      * heightfield.
      */
-    dInitODE();
     {
         // Create quick heightfield with dummy data
         dHeightfieldDataID heightfieldData = dGeomHeightfieldDataCreate();
@@ -99,13 +116,12 @@ TEST(test_collision_heightfield_ray_fail)
         dGeomRaySet(ray, 5, 10, 1, 0, -1, 0);
         dContact contactBuf[10];
 
-        // Crash!
+        // Make sure it does not crash!
         dCollide(ray, height, 10, &(contactBuf[0].geom), sizeof(dContact));
 
         dGeomDestroy(height);
         dGeomDestroy(ray);
         dGeomHeightfieldDataDestroy(heightfieldData);
     }
-    dCloseODE();
 }
 
